"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const touchable_1 = require("./utils/touchable");
const SceneUtils_1 = __importDefault(require("../../utils/SceneUtils"));
class FloatingActionItem extends react_1.default.Component {
    constructor(props) {
        super(props);
        this.handleOnPress = () => {
            const { name, onPress } = this.props;
            onPress(name);
        };
        this.animation = new react_native_1.Animated.Value(0);
    }
    componentDidUpdate(prevProps) {
        const { active, animated } = this.props;
        if (prevProps.active !== active && animated) {
            react_native_1.Animated.spring(this.animation, {
                toValue: active ? 1 : 0,
                useNativeDriver: false
            }).start();
        }
    }
    get distanceToHorizontalEdge() {
        const { distanceToEdge } = this.props;
        return typeof distanceToEdge === 'number'
            ? distanceToEdge
            : distanceToEdge === null || distanceToEdge === void 0 ? void 0 : distanceToEdge.horizontal;
    }
    get distanceToVerticalEdge() {
        const { distanceToEdge } = this.props;
        return typeof distanceToEdge === 'number'
            ? distanceToEdge
            : distanceToEdge === null || distanceToEdge === void 0 ? void 0 : distanceToEdge.vertical;
    }
    renderText() {
        const { text, position, textColor, textStyle, textProps, textContainerStyle, } = this.props;
        if (text) {
            return (react_1.default.createElement(react_native_1.View, { key: "text", style: [
                    styles.textContainer,
                    // styles[`${position}TextContainer`],
                    styles.rightTextContainer,
                    textContainerStyle
                ] },
                react_1.default.createElement(react_native_1.Text, Object.assign({ style: [
                        styles.text,
                        {
                            color: textColor
                        },
                        textStyle
                    ] }, textProps), text),
                this.props.text === 'GO TO BAG' &&
                    react_1.default.createElement(react_native_1.View, { style: styles.countContainer },
                        react_1.default.createElement(react_native_1.Text, { style: styles.countText }, this.props.cartCount))));
        }
        return null;
    }
    renderButton() {
        const { buttonSize, icon, color, shadow, tintColor } = this.props;
        // if (icon && icon.uri) {
        //   iconStyle = styles.iconLogo;
        // } else {
        //   iconStyle = styles.icon;
        // }
        const propStyles = {
            tintColor: tintColor,
            backgroundColor: color,
            width: buttonSize,
            height: buttonSize,
            borderRadius: buttonSize / 2
        };
        return (react_1.default.createElement(react_native_1.View, { key: "button", style: styles.button },
            react_1.default.createElement(react_native_1.Image, { style: styles.icon, source: icon })));
    }
    render() {
        const { position, render, margin, name, animated } = this.props;
        const Touchable = (0, touchable_1.getTouchableComponent)(false);
        let animatedActionContainerStyle;
        if (animated) {
            animatedActionContainerStyle = {
                marginBottom: this.animation.interpolate({
                    inputRange: [0, 1],
                    outputRange: [1, 3]
                })
            };
        }
        else {
            animatedActionContainerStyle = { marginBottom: 6 };
        }
        const components = [];
        components.push(this.renderButton());
        components.push(this.renderText());
        return (react_1.default.createElement(Touchable, { activeOpacity: 0.4, style: styles.container },
            react_1.default.createElement(react_native_1.TouchableOpacity, { onPress: this.handleOnPress },
                react_1.default.createElement(react_native_1.Animated.View, { style: [
                        styles.actionContainer,
                        animatedActionContainerStyle,
                        // styles[`${position}ActionContainer`],
                        styles.rightTextContainer,
                        {
                            borderTopLeftRadius: this.props.index === 0 ? 6 : 0,
                            borderTopRightRadius: this.props.index === 0 ? 6 : 0,
                            borderBottomLeftRadius: this.props.index === 1 ? 6 : 0,
                            borderBottomRightRadius: this.props.index === 1 ? 6 : 0
                        }
                    ] }, components))));
    }
}
// FloatingActionItem.propTypes = {
//   tintColor: PropTypes.string,
//   color: PropTypes.string,
//   icon: PropTypes.any,
//   name: PropTypes.string.isRequired,
//   buttonSize: PropTypes.number,
//   textContainerStyle: PropTypes.object,
//   text: PropTypes.string,
//   textStyle: PropTypes.object,
//   textProps: PropTypes.object,
//   textBackground: PropTypes.string,
//   textColor: PropTypes.string,
//   shadow: PropTypes.shape({
//     shadowOpacity: PropTypes.number,
//     shadowOffset: PropTypes.shape({
//       width: PropTypes.number,
//       height: PropTypes.number
//     }),
//     shadowColor: PropTypes.string,
//     shadowRadius: PropTypes.number
//   }),
//   // not modified by user
//   position: PropTypes.oneOf(["left", "right", "center"]),
//   active: PropTypes.bool,
//   distanceToEdge: PropTypes.oneOfType([
//     PropTypes.number,
//     PropTypes.shape({
//       vertical: PropTypes.number,
//       horizontal: PropTypes.number
//     })
//   ]), // modified by parent property "actionsPaddingTopBottom"
//   onPress: PropTypes.func,
//   render: PropTypes.func,
//   margin: PropTypes.number,
//   animated: PropTypes.bool
// };
// FloatingActionItem.defaultProps = {
//   tintColor: '#fff',
//   color: SceneUtils.primary_color,
//   distanceToEdge: 30,
//   buttonSize: 40,
//   textColor: SceneUtils.text_color,
//   textBackground: "#ffffff",
//   margin: 8,
//   shadow: {
//     shadowOpacity: 0.35,
//     shadowOffset: {
//       width: 0,
//       height: 5
//     },
//     shadowColor: "#000000",
//     shadowRadius: 3
//   }
// };
const styles = react_native_1.StyleSheet.create({
    container: {
        flex: 1,
        flexDirection: "column"
    },
    actionContainer: {
        flex: 1,
        flexDirection: "row",
        alignItems: 'center',
        paddingLeft: 0,
        paddingRight: 0,
        backgroundColor: '#FFF',
        width: 220,
        marginRight: 30,
        height: 48
    },
    textContainer: {
        paddingHorizontal: 5,
        borderRadius: 4,
        height: 22,
        flexDirection: 'row',
        flex: 1
    },
    leftTextContainer: {
        marginLeft: 14
    },
    rightTextContainer: {
        marginRight: 14
    },
    text: {
        fontSize: 14,
        lineHeight: 20,
        fontFamily: SceneUtils_1.default.whitney_semibold
    },
    button: {
        alignItems: "center",
        justifyContent: "center",
        marginHorizontal: 14
    },
    iconLogo: {
        resizeMode: "cover",
        width: 40,
        height: 40,
        borderRadius: 20
    },
    icon: {
        resizeMode: "contain",
        width: 20,
        height: 20
    },
    countContainer: {
        width: 24,
        height: 24,
        backgroundColor: SceneUtils_1.default.primary_color,
        justifyContent: 'center',
        alignItems: 'center',
        borderRadius: 12,
        position: 'absolute',
        right: 0
    },
    countText: {
        color: 'white',
        fontWeight: 'bold',
        fontSize: 12
    }
});
exports.default = FloatingActionItem;
//# sourceMappingURL=FloatingActionItem.js.map